# Changelog
Note: version releases in the 0.x.y range may introduce breaking changes.

## 1.5.0

- minor: Added xai, groq, deepseek and openrouter as openai compat endpoints

## 1.4.0

- minor: feat: added multi-tenacy kinda logic for websocket and sse

## 1.3.0

- minor: Added support for Stateful agents. Agent base class support persistence, message history, and lifecycle hooks

## 1.2.0

- minor: Experimental MCP support, with stdio, sse and streamable http transport

## 1.1.0

- minor: Refactor tool definition to use `@tool` decorator and `Field` for parameters, updating examples and adding new tests and agent

## 1.0.0

- major: Added tool calling support

## 0.0.3

- patch: docs: added project urls

## 0.0.2

- patch: docs: add comprehensive usage guide and provider configuration details

## 0.0.1

- patch: Refactor providers to use base class fetching and fix OpenAI image fetching
